// This file is part of the Attempto Java Packages.
// Copyright 2008-2009, Attempto Group, University of Zurich (see http://attempto.ifi.uzh.ch).
//
// The Attempto Java Packages is free software: you can redistribute it and/or modify it under the
// terms of the GNU Lesser General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// The Attempto Java Packages is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
// PURPOSE. See the GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License along with the Attempto
// Java Packages. If not, see http://www.gnu.org/licenses/.

package ch.uzh.ifi.attempto.aceeditor;

import java.util.HashMap;

import ch.uzh.ifi.attempto.chartparser.Category;
import ch.uzh.ifi.attempto.chartparser.Restriction;
import ch.uzh.ifi.attempto.chartparser.Terminal;
import ch.uzh.ifi.attempto.preditor.MenuCreator;
import ch.uzh.ifi.attempto.preditor.text.TextElement;

/**
 * This is the menu creator class for the ACE Editor.
 * 
 * @author Tobias Kuhn
 */
class ACEEditorMenuCreator extends MenuCreator {

	private static HashMap<String, String> categories = new HashMap<String, String>();
	private LexiconHandler lexiconHandler;

	static {
		categories.put("NOUN_SG", "noun");
		categories.put("NOUN_PL", "noun");
		categories.put("PN_SG", "proper name");
		categories.put("PNDEF_SG", "proper name");
		categories.put("IV_FINSG", "intransitive verb");
		categories.put("IV_INFPL", "intransitive verb");
		categories.put("TV_FINSG", "transitive verb");
		categories.put("TV_INFPL", "transitive verb");
		categories.put("TV_PP", "passive verb");
		categories.put("ADJ_ITR", "adjective");
		categories.put("ADJ_ITR_COMP", "adjective");
		categories.put("ADJ_ITR_SUP", "adjective");
		categories.put("ADJ_TR", "transitive adjective");
		categories.put("ADJ_TR_COMP", "transitive adjective");
		categories.put("ADV", "adverb");
		categories.put("ADV_COMP", "adverb");
		categories.put("ADV_SUP", "adverb");
		categories.put("PREP", "preposition");
	}

	ACEEditorMenuCreator(LexiconHandler lexiconHandler) {
		this.lexiconHandler = lexiconHandler;
	}

	public void initMenuCreation() {
		prepareMenuBlock("function word", true);
		prepareMenuBlock("proper name", true);
		prepareMenuBlock("noun", true);
		prepareMenuBlock("adjective", true);
		prepareMenuBlock("transitive adjective", true);
		prepareMenuBlock("intransitive verb", true);
		prepareMenuBlock("transitive verb", true);
		prepareMenuBlock("adverb", true);
		prepareMenuBlock("preposition", true);
		prepareMenuBlock("new variable", false);
		prepareMenuBlock("reference", false);
	}

	public void addMenuItems(Restriction restriction) {
		Category c = restriction.getCategory();
		String n = c.getName();

		if (n.equals("ADJ_TR_PREP")) {
			addMenuEntry("preposition", new TextElement(c.getFeature("prep").getString(), (Terminal) c.deepCopy()));
		} else if (n.equals("PNDEF_SG")) {
			for (Word w : lexiconHandler.getWordsByType(n)) {
				addMenuEntry(categories.get(n), new TextElement("the " + w.getText(), w.getCategoryCopy()));
			}
		} else if (n.equals("DEF_NOUN_SG")) {
			for (Word w : lexiconHandler.getWordsByType("NOUN_SG")) {
				Terminal cat = new Terminal("DEF_NOUN_SG");
				cat.setFeature("noun", w.getText());
				cat.setFeature("text", "the " + w.getText());
				addMenuEntry("reference", new TextElement("the " + w.getText(), cat));
			}
		} else if (categories.containsKey(n)) {
			for (Word w : lexiconHandler.getWordsByType(n)) {
				addMenuEntry(categories.get(n), new TextElement(w.getText(), w.getCategoryCopy()));
			}
		} else if (n.equals("VAR")) {
			addVariableEntries("new variable", 5, "VAR");
		} else if (n.equals("REF")) {
			addVariableEntries("reference", 5, "REF");
		} else if (n.equals("NUM")) {
			for (int i = 2 ; i < 400 ; i++) {
				addMenuEntry("function word", new TextElement(i + "", n));
			}
		} else {
			addMenuEntry("function word", new TextElement(n));
		}
	}

}

