// This file is part of the Attempto Java Packages.
// Copyright 2008-2009, Attempto Group, University of Zurich (see http://attempto.ifi.uzh.ch).
//
// The Attempto Java Packages is free software: you can redistribute it and/or modify it under the
// terms of the GNU Lesser General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// The Attempto Java Packages is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
// PURPOSE. See the GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License along with the Attempto
// Java Packages. If not, see http://www.gnu.org/licenses/.

package ch.uzh.ifi.attempto.aceeditor;

import nextapp.echo2.app.ApplicationInstance;
import nextapp.echo2.app.Window;
import nextapp.echo2.webcontainer.ContainerContext;
import nextapp.echo2.webcontainer.WebContainerServlet;
import ch.uzh.ifi.attempto.ape.APELocal;
import ch.uzh.ifi.attempto.echocomp.ServerDelayMessage;
import ch.uzh.ifi.attempto.echocomp.Style;

/**
 * This servlet class is used by the web server to start the ACE Editor.
 * 
 * @author Tobias Kuhn
 */
public class ACEEditorServlet extends WebContainerServlet {

	private static final long serialVersionUID = -2533205689651186115L;

	/**
	 * Creates a new ACE Editor servlet.
	 */
	public ACEEditorServlet() {
	}

	public ApplicationInstance newApplicationInstance() {

		return new ApplicationInstance() {

			private static final long serialVersionUID = 2982410120358060245L;

			public Window init() {
				setStyleSheet(Style.styleSheet);

				if (!APELocal.isInitialized()) {
					String apeCommand = getServletContext().getInitParameter("apecommand");
					if (apeCommand == null) apeCommand = "ape.exe";
					APELocal.init(apeCommand);
				}
				
				ContainerContext cc = (ContainerContext) ApplicationInstance.getActive().getContextProperty(ContainerContext.CONTEXT_PROPERTY_NAME);
				cc.setServerDelayMessage(new ServerDelayMessage("Please wait...", "../wait.gif"));
				// (The wait icon should be copied at the right place on the server.)
				
				String lexiconFile = getInitParameter("lexicon");
				if (lexiconFile == null) lexiconFile = "lexicon.pl";
				boolean parseWithClexEnabled = !"off".equals(getInitParameter("parse_with_clex"));
				return new ACEEditor(lexiconFile, parseWithClexEnabled);
			}

		};

	}

}
