// This file is part of the Attempto Java Packages.
// Copyright 2008-2009, Attempto Group, University of Zurich (see http://attempto.ifi.uzh.ch).
//
// The Attempto Java Packages is free software: you can redistribute it and/or modify it under the
// terms of the GNU Lesser General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// The Attempto Java Packages is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
// PURPOSE. See the GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License along with the Attempto
// Java Packages. If not, see http://www.gnu.org/licenses/.

package ch.uzh.ifi.attempto.aceeditor;

import java.io.FileInputStream;
import java.util.ArrayList;
import java.util.HashMap;

import ch.uzh.ifi.attempto.ape.Lexicon;
import ch.uzh.ifi.attempto.ape.LexiconEntry;

class LexiconHandler {

	private Lexicon lexicon = new Lexicon();
	private HashMap<String,ArrayList<Word>> categoryMap = new HashMap<String,ArrayList<Word>>();
	private HashMap<String,ArrayList<Word>> textMap = new HashMap<String,ArrayList<Word>>();

	public LexiconHandler(String lexiconFile) {
		try {
			FileInputStream in = new FileInputStream(lexiconFile);
			byte[] bytes = new byte[in.available()];
			in.read(bytes);
			in.close();
			String[] lines = (new String(bytes)).split("\n");
			for (String s : lines) {
				Word word = new Word(s);
				String w = word.getWord();
				if (w == null) continue;
				String catName = word.getCategory().getName();

				lexicon.addEntry(LexiconEntry.createEntry(word.getEntry()));

				if (categoryMap.get(catName) == null) {
					categoryMap.put(catName, new ArrayList<Word>());
				}
				categoryMap.get(catName).add(word);

				if (textMap.get(w) == null) {
					textMap.put(w, new ArrayList<Word>());
				}
				textMap.get(w).add(word);
			}
		} catch (Exception ex) {
			ex.printStackTrace();
		}
	}

	public Lexicon getLexicon() {
		return lexicon;
	}

	public ArrayList<Word> getWordsByType(String type) {
		ArrayList<Word> l = categoryMap.get(type);
		if (l == null) l = new ArrayList<Word>();
		return l;
	}

	public ArrayList<Word> getWordsByText(String text) {
		ArrayList<Word> l = textMap.get(text);
		if (l == null) l = new ArrayList<Word>();
		return l;
	}

}
