// This file is part of the Attempto Java Packages.
// Copyright 2008-2009, Attempto Group, University of Zurich (see http://attempto.ifi.uzh.ch).
//
// The Attempto Java Packages is free software: you can redistribute it and/or modify it under the
// terms of the GNU Lesser General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// The Attempto Java Packages is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
// PURPOSE. See the GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License along with the Attempto
// Java Packages. If not, see http://www.gnu.org/licenses/.

package ch.uzh.ifi.attempto.aceeditor;

import java.util.ArrayList;
import java.util.HashMap;

import nextapp.echo2.app.Alignment;
import nextapp.echo2.app.Button;
import nextapp.echo2.app.Color;
import nextapp.echo2.app.Column;
import nextapp.echo2.app.Extent;
import nextapp.echo2.app.Font;
import nextapp.echo2.app.Insets;
import nextapp.echo2.app.Row;
import nextapp.echo2.app.event.ActionEvent;
import nextapp.echo2.app.event.ActionListener;
import nextapp.echo2.app.layout.RowLayoutData;
import ch.uzh.ifi.attempto.ape.ACEParser;
import ch.uzh.ifi.attempto.ape.ACEParserResult;
import ch.uzh.ifi.attempto.ape.APELocal;
import ch.uzh.ifi.attempto.ape.Lexicon;
import ch.uzh.ifi.attempto.ape.OutputType;
import ch.uzh.ifi.attempto.echocomp.Style;

class TextEntry extends Column implements ActionListener {

	private static final long serialVersionUID = -1976178070379593477L;

	private static ACEParser aceParser = APELocal.getInstance();
	//private static ACEParser aceParser = new APEWebservice("http://attempto.ifi.uzh.ch/ws/ape/apews.perl");

	private HashMap<String,ResultItem> resultItems = new HashMap<String,ResultItem>();

	private boolean selected = false;
	private boolean expanded = true;
	private boolean error = false;
	private boolean comment = false;
	private ACEEditor owner;
	private String aceText;

	private Column resultsColumn;
	private Button sentenceButton, expandButton;


	public TextEntry(String aceText, ACEEditor owner) {
		this(aceText, owner, null, false);
	}

	public TextEntry(String aceText, ACEEditor owner, boolean expanded) {
		this(aceText, owner, null, expanded);
	}

	private TextEntry(String aceText, ACEEditor owner, HashMap<String,ResultItem> resultItemsTemplate, boolean expanded) {
		this.owner = owner;
		this.expanded = expanded;
		if (aceText == null || aceText.matches("\\s*")) {
			this.aceText = null;
		} else {
			this.aceText = aceText.replaceAll("\\s+", " ");
		}

		Row sentenceRow = new Row();
		sentenceRow.setInsets(new Insets(0, 0, 5, 0));
		RowLayoutData layout = new RowLayoutData();
		layout.setAlignment(new Alignment(Alignment.LEFT, Alignment.TOP));

		expandButton = new Button();
		expandButton.setFont(new Font(Style.fontTypeface, Font.BOLD, new Extent(13)));
		expandButton.setAlignment(new Alignment(Alignment.CENTER, Alignment.CENTER));
		expandButton.setInsets(new Insets(0, 1, 0, 0));
		expandButton.setWidth(new Extent(20));
		expandButton.setHeight(new Extent(19));
		expandButton.setRolloverEnabled(true);
		expandButton.setRolloverBackground(Style.lightBackground);
		expandButton.addActionListener(this);
		expandButton.setLayoutData(layout);
		sentenceRow.add(expandButton);

		sentenceButton = new Button();
		sentenceButton.setFont(new Font(Style.fontTypeface, Font.PLAIN, new Extent(13)));
		sentenceButton.setInsets(new Insets(4, 1, 4, 2));
		sentenceButton.setRolloverEnabled(true);
		sentenceButton.addActionListener(this);
		sentenceButton.setLayoutData(layout);
		sentenceRow.add(sentenceButton);

		add(sentenceRow);

		resultsColumn = new Column();
		resultsColumn.setInsets(new Insets(25, 5, 5, 5));
		if (aceText != null) {
			ArrayList<ResultItem> l = new ArrayList<ResultItem>();

			l.add(createResultItem(ResultItem.PARAPHRASE, resultItemsTemplate));
			l.add(createResultItem(ResultItem.SENTENCES, resultItemsTemplate));
			l.add(createResultItem(ResultItem.TOKENS, resultItemsTemplate));
			l.add(createResultItem(ResultItem.SYNTAX_LIST, resultItemsTemplate));
			l.add(createResultItem(ResultItem.SYNTAX_TREE, resultItemsTemplate));
			l.add(createResultItem(ResultItem.SYNTAX_BOXES, resultItemsTemplate));
			l.add(createResultItem(ResultItem.DRS_PROLOG, resultItemsTemplate));
			l.add(createResultItem(ResultItem.DRS_PRETTY, resultItemsTemplate));
			l.add(createResultItem(ResultItem.DRS_XML, resultItemsTemplate));
			l.add(createResultItem(ResultItem.FOL, resultItemsTemplate));
			l.add(createResultItem(ResultItem.PNF, resultItemsTemplate));
			l.add(createResultItem(ResultItem.OWL_FSS, resultItemsTemplate));
			l.add(createResultItem(ResultItem.OWL_RDF, resultItemsTemplate));
			l.add(createResultItem(ResultItem.OWL_XML, resultItemsTemplate));

			for (ResultItem ri : l) {
				resultItems.put(ri.getName(), ri);
				resultsColumn.add(ri);
			}

			if (expanded) {
				add(resultsColumn);
			}
		}

		update();
	}

	private ResultItem createResultItem(String name, HashMap<String,ResultItem> template) {
		if (template == null) {
			return new ResultItem(name);
		} else {
			return template.get(name).copy();
		}
	}

	private void update() {
		if (aceText == null) {
			expandButton.setText("+");
			sentenceButton.setHeight(new Extent(17));
		} else if (aceText.startsWith("# ")) {
			expandButton.setText("#");
			sentenceButton.setText(aceText.substring(2));
			comment = true;
		} else {
			expandButton.setText(">");
			sentenceButton.setText(aceText);

			aceParser.setURI("http://attempto.ifi.uzh.ch/aceeditor/default");
			Lexicon lexicon;
			if (owner.isParseWithClexEnabled()) {
				aceParser.setClexEnabled(true);
				lexicon = null;
			} else {
				aceParser.setClexEnabled(false);
				lexicon = owner.getLexiconHandler().getLexicon();
			}
			// TODO: submit only the part of the lexicon that is needed.
			ACEParserResult parserResult = aceParser.getMultiOutput(aceText, lexicon,
					OutputType.PARAPHRASE,
					OutputType.SENTENCES,
					OutputType.TOKENS,
					OutputType.SYNTAX,
					OutputType.SYNTAXPP,
					OutputType.DRS,
					OutputType.DRSPP,
					OutputType.DRSXML,
					OutputType.FOL,
					OutputType.PNF,
					OutputType.OWLFSSPP,
					OutputType.OWLRDF,
					OutputType.OWLXML
			);

			for (ResultItem ri : resultItems.values()) {
				ri.setContent(parserResult);
			}

			error = parserResult.get(OutputType.DRS).equals("drs([], [])");
		}

		setSelected(selected);
	}

	/*
	private String[] tokenize(String s) {
		s = s.replaceAll("\\.\\s", " . ");
		s = s.replaceAll("\\.$", " . ");
		s = s.replaceAll("\\,\\s", " , ");
		s = s.replaceAll("\\!\\s", " ! ");
		s = s.replaceAll("\\!$", " ! ");
		s = s.replaceAll("\\?\\s", " ? ");
		s = s.replaceAll("\\?$", " ? ");
		s = s.replaceAll("\\s+", " ");
		return s.split("\\s");
	}
	 */

	public String getAceText() {
		return aceText;
	}

	public void setAceText(String aceText) {
		if (aceText == null || aceText.matches("\\s*")) {
			this.aceText = null;
		} else {
			this.aceText = aceText.replaceAll("\\s+", " ");
		}
		update();
	}

	public void setSelected(boolean selected) {
		this.selected = selected;
		if (comment) {
			sentenceButton.setFont(new Font(Style.fontTypeface, Font.ITALIC, new Extent(13)));
		} else {
			sentenceButton.setFont(new Font(Style.fontTypeface, Font.PLAIN, new Extent(13)));
		}
		if (selected) {
			sentenceButton.setBackground(Style.mediumBackground);
			sentenceButton.setRolloverBackground(Style.mediumBackground);
			if (error) {
				sentenceButton.setForeground(Color.RED);
				sentenceButton.setRolloverForeground(Color.RED);
			} else if (comment) {
				sentenceButton.setForeground(new Color(240, 240, 240));
				sentenceButton.setRolloverForeground(new Color(240, 240, 240));
			} else {
				sentenceButton.setForeground(Color.WHITE);
				sentenceButton.setRolloverForeground(Color.WHITE);
			}
		} else {
			sentenceButton.setBackground(Color.WHITE);
			sentenceButton.setRolloverBackground(Style.lightBackground);
			if (error) {
				sentenceButton.setForeground(Color.RED);
				sentenceButton.setRolloverForeground(Color.RED);
			} else if (comment) {
				sentenceButton.setForeground(Color.DARKGRAY);
				sentenceButton.setRolloverForeground(Color.DARKGRAY);
			} else {
				sentenceButton.setForeground(Color.BLACK);
				sentenceButton.setRolloverForeground(Color.BLACK);
			}
		}
	}

	public void setResultItemVisible(String name, boolean visible) {
		ResultItem ri = resultItems.get(name);
		if (ri != null) {
			ri.setVisible(visible);
		}
	}

	public boolean isResultItemVisible(String name) {
		return resultItems.get(name).isVisible();
	}

	public boolean isEmpty() {
		return aceText == null;
	}

	public boolean isExpanded() {
		return expanded;
	}

	public boolean hasError() {
		return error;
	}

	public boolean isComment() {
		return comment;
	}

	public void setExpanded(boolean expanded) {
		if (this.expanded == expanded || aceText == null || error || comment) {
			return;
		}
		this.expanded = expanded;
		if (expanded) {
			add(resultsColumn);
		} else {
			remove(resultsColumn);
		}
		owner.entryChanged(this);
	}

	public void actionPerformed(ActionEvent e) {
		if (e.getSource() == expandButton && !error && !comment) {
			if (aceText == null) {
				owner.actionPerformed(new ActionEvent(this, "Add..."));
				owner.select(this);
			} else {
				if (expanded) {
					setExpanded(false);
				} else {
					setExpanded(true);
				}
			}
		} else if (e.getSource() == sentenceButton) {
			owner.select(this);
		}
	}

	public TextEntry copy() {
		TextEntry copy = new TextEntry(aceText, owner, resultItems, expanded);
		copy.selected = selected;
		return copy;
	}

}
