// This file is part of the Attempto Java Packages.
// Copyright 2008-2009, Attempto Group, University of Zurich (see http://attempto.ifi.uzh.ch).
//
// The Attempto Java Packages is free software: you can redistribute it and/or modify it under the
// terms of the GNU Lesser General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// The Attempto Java Packages is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
// PURPOSE. See the GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License along with the Attempto
// Java Packages. If not, see http://www.gnu.org/licenses/.

package ch.uzh.ifi.attempto.aceeditor;

import ch.uzh.ifi.attempto.chartparser.Terminal;

class Word {

	private String text, lexem, entry;
	private Terminal category;

	public Word(String lexiconEntry) {
		if (lexiconEntry.matches("[a-z_]+\\('?[A-Za-z0-9-_]+'?,\\s*'?[A-Za-z0-9-_]+'?.*\\)\\.\\s*")) {
			entry = lexiconEntry.replaceFirst("^(.*)\\.\\s*$", "$1");
			category = new Terminal(lexiconEntry.replaceFirst("^([a-z_]+)\\(.*$", "$1").toUpperCase());
			text = lexiconEntry.replaceFirst("^[a-z_]+\\('?([A-Za-z0-9-_]+)'?,.*$", "$1");
			lexem = lexiconEntry.replaceFirst("^[a-z_]+\\('?[A-Za-z0-9-_]+'?,\\s*'?([A-Za-z0-9-_]+)'?.*$", "$1");
			readFeatures(lexiconEntry.replaceFirst("^[a-z_]+\\('?[A-Za-z0-9-_]+'?,\\s*'?[A-Za-z0-9-_]+'?(.*)\\)\\.\\s*", "$1"));
			category.setFeature("text", text);
		} else if (!lexiconEntry.equals("")) {
			System.err.println("WARNING: Invalid lexicon entry: " + lexiconEntry);
		}
	}

	public String getText() {
		return text;
	}

	public String getWord() {
		return text;
	}

	public String getLexem() {
		return lexem;
	}

	public String getEntry() {
		return entry;
	}

	public Terminal getCategory() {
		return category;
	}

	public Terminal getCategoryCopy() {
		return (Terminal) category.deepCopy();
	}

	private void readFeatures(String featureString) {
		String[] s = featureString.replaceAll("\\s+", "").replaceFirst("^,", "").split(",");

		String n = category.getName();
		if (n.equals("ADJ_TR") || n.equals("ADJ_TR_COMP")) {
			category.setFeature("prep", s[0]);
		} else if (n.equals("NOUN_SG") || n.equals("NOUN_PL") || n.equals("PN_SG") || n.equals("PNDEF_SG")) {
			if (s[0].equals("masc") || s[0].equals("fem")) {
				category.setFeature("human", "plus");
				category.setFeature("gender", s[0]);
			} else if (s[0].equals("human")) {
				category.setFeature("human", "plus");
			} else {
				category.setFeature("human", "minus");
			}
		}
		if (n.equals("PN_SG")) {
			category.setFeature("capitalize", "false");
		}
	}

}
