// This file is part of the Attempto Java Packages.
// Copyright 2008-2009, Attempto Group, University of Zurich (see http://attempto.ifi.uzh.ch).
//
// The Attempto Java Packages is free software: you can redistribute it and/or modify it under the
// terms of the GNU Lesser General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// The Attempto Java Packages is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
// PURPOSE. See the GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License along with the Attempto
// Java Packages. If not, see http://www.gnu.org/licenses/.

package ch.uzh.ifi.attempto.preditor.example;

import ch.uzh.ifi.attempto.chartparser.Restriction;
import ch.uzh.ifi.attempto.preditor.MenuCreator;
import ch.uzh.ifi.attempto.preditor.text.TextElement;

/**
 * This class is an examplary implementation of a menu creator. See the
 * <a href="{@docRoot}/src-html/ch/uzh/ifi/attempto/preditor/example/ExampleMenuCreator.html#line.1">source code</a>.
 * 
 * @author Tobias Kuhn
 */
public class ExampleMenuCreator extends MenuCreator {
	
	/**
	 * Creates a new menu creator instance.
	 */
	public ExampleMenuCreator() {
	}
	
	public void initMenuCreation() {
		// Here we can define the order of the menu blocks and whether they should be sorted or not:
		prepareMenuBlock("function word", true);
		prepareMenuBlock("determiner", true);
		prepareMenuBlock("noun", true);
		prepareMenuBlock("proper name", true);
		prepareMenuBlock("intransitive verb", true);
		prepareMenuBlock("transitive verb", true);
	}

	public void addMenuItems(Restriction restriction) {
		String n = restriction.getCategory().getName();
		
		if (n.equals("DET")) {
			addMenuEntry("determiner", new TextElement("a", n));
			addMenuEntry("determiner", new TextElement("no", n));
			addMenuEntry("determiner", new TextElement("every", n));
		} else if (n.equals("N")) {
			addMenuEntry("noun", new TextElement("man", n));
			addMenuEntry("noun", new TextElement("woman", n));
			addMenuEntry("noun", new TextElement("human", n));
			addMenuEntry("noun", new TextElement("dog", n));
			addMenuEntry("noun", new TextElement("house", n));
			addMenuEntry("noun", new TextElement("car", n));
		} else if (n.equals("PN")) {
			addMenuEntry("proper name", new TextElement("John", n));
			addMenuEntry("proper name", new TextElement("Bill", n));
			addMenuEntry("proper name", new TextElement("Mary", n));
			addMenuEntry("proper name", new TextElement("Sue", n));
			addMenuEntry("proper name", new TextElement("Tom", n));
			addMenuEntry("proper name", new TextElement("Rick", n));
			addMenuEntry("proper name", new TextElement("Paul", n));
		} else if (n.equals("IV")) {
			addMenuEntry("intransitive verb", new TextElement("waits", n));
			addMenuEntry("intransitive verb", new TextElement("sleeps", n));
			addMenuEntry("intransitive verb", new TextElement("works", n));
			addMenuEntry("intransitive verb", new TextElement("eats", n));
			addMenuEntry("intransitive verb", new TextElement("drinks", n));
		} else if (n.equals("TV")) {
			addMenuEntry("transitive verb", new TextElement("sees", n));
			addMenuEntry("transitive verb", new TextElement("knows", n));
			addMenuEntry("transitive verb", new TextElement("owns", n));
			addMenuEntry("transitive verb", new TextElement("uses", n));
			addMenuEntry("transitive verb", new TextElement("buys", n));
			addMenuEntry("transitive verb", new TextElement("sells", n));
			addMenuEntry("transitive verb", new TextElement("drives", n));
			addMenuEntry("transitive verb", new TextElement("likes", n));
		} else {
			addMenuEntry("function word", new TextElement(n));
		}
	}

}
